@@ -1,6 +1,6 @@
 package Dist::Iller;
 
-our $VERSION = '0.1202'; # VERSION
+our $VERSION = '0.1203'; # VERSION
 
 use strict;
 use warnings;
@@ -22,21 +22,23 @@ Dist::Iller - A Dist::Zilla & Pod::Weaver preprocessor
 
 =head1 VERSION
 
-Version 0.1202, released 2015-11-27.
+Version 0.1203, released 2016-01-09.
 
 =head1 SYNOPSIS
 
-    $ iller new -P DistIller::AMintingProvider My::Module
+    # dzil new, but... 
+    $ dzil new -P DistIller::AMintingProvider My::Module
 
     $ cd My/Module
 
+    # ...all other commands can be used via iller
     $ iller build
 
 =head1 STATUS
 
 This is alpha software. Anything can change at any time.
 
-It is mostly here to document how I build my distributions. It is perfectly fine to use C<dzil> with a C<Dist::Iller> built distribution (after a fork, for example).
+It is mostly here to document how I build my distributions. It is perfectly fine to use C<dzil> with a distribution built with C<Dist::Iller> (after a fork, for example).
 
 =head1 DESCRIPTION
 
@@ -130,11 +132,11 @@ Difficult to insert a plugin before another plugin for a certain distribution.
 
 =item *
 
-Difficult for others to understand which plugins actually were in effect when building the distribution.
+PluginBundles can change after a distribution has been released.
 
 =item *
 
-PluginBundles can change after a distribution has been released.
+Difficult for others to understand/know which plugins actually were in effect when the distribution was built.
 
 =back
 
@@ -144,7 +146,11 @@ C<Dist::Iller> tries to solve this:
 
 =item *
 
-Dist::Iller configs (similar to PluginBundles) also has a separate C<iller.yaml> (normally in C<share/>) for specifying which plugins it includes. See tests and L<Dist::Iller::Config::Author::CSSON>).
+Dist::Iller configs (similar to PluginBundles) has their own C<iller.yaml> (normally in C<share/>) where plugins are specified. See tests and L<Dist::Iller::Config::Author::CSSON>).
+
+=item *
+
+Since C<dist.ini> and C<weaver.ini> are generated each time C<iller> is run, the plugins listed in them are those that were used to build the distribution.
 
 =item *
 
@@ -188,14 +194,6 @@ Set more attributes for an already included plugin:
         exclude_match:
           - examples/.*\.html
 
-=over 4
-
-=item *
-
-Since C<dist.ini> and C<weaver.ini> are generated each time C<iller> is run, the plugins listed in them are those that were used to build the distribution.
-
-=back
-
 =head1 SEE ALSO
 
 =over 4
@@ -228,7 +226,7 @@ Erik Carlsson <info@code301.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by Erik Carlsson.
+This software is copyright (c) 2016 by Erik Carlsson.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
