@@ -3,10 +3,9 @@ use strict;
 use warnings;
 
 
-package #
-    Dist::Iller::Standard {
+package Dist::Iller::Standard {
 
-    our $VERSION = '0.1202'; # VERSION
+    our $VERSION = '0.1203'; # VERSION
 
     use base 'Moops';
     use List::AllUtils();
@@ -50,7 +49,7 @@ Dist::Iller::Standard
 
 =head1 VERSION
 
-Version 0.1202, released 2015-11-27.
+Version 0.1203, released 2016-01-09.
 
 =head1 SOURCE
 
@@ -66,7 +65,7 @@ Erik Carlsson <info@code301.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by Erik Carlsson.
+This software is copyright (c) 2016 by Erik Carlsson.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
